;; Generated package description from on-screen.el  -*- no-byte-compile: t -*-
(define-package "on-screen" "1.3.3.0.20201127.191411" "guide your eyes while scrolling" '((cl-lib "0")) :commit "643a866f578d04d81a1fa6fd6a61dd49d80c23b3" :authors '(("Michael Heerdegen" . "michael_heerdegen@web.de")) :maintainer '("Michael Heerdegen" . "michael_heerdegen@web.de") :keywords '("convenience") :url "https://github.com/michael-heerdegen/on-screen.el")
